@@ -5,6 +5,7 @@
 
 static Oid oidHstore = 0;
 
+
 Oid GetHstoreOid() {
     return oidHstore;
 }
@@ -75,3 +76,42 @@ PyObject* GetHstore(const char* p)
 
     return result.Detach();
 }
+
+
+static PyObject* Hstore_new(PyTypeObject* type, PyObject* args, PyObject* kwds)
+{
+    PyObject* dict;
+    if (!PyArg_ParseTuple(args, "O", &dict) || !PyDict_Check(dict))
+    {
+        PyErr_SetString(Error, "hstore constructor requires a single dictionary");
+        return 0;
+    }
+
+    Hstore* self = (Hstore*)type->tp_alloc(type, 0);
+    if (self == 0)
+        return 0;
+
+    self->data = dict;
+    Py_INCREF(self->data);
+
+    return (PyObject*)self;
+}
+
+
+static void Hstore_dealloc(PyObject* self)
+{
+    Hstore* hstore = (Hstore*)self;
+    Py_XDECREF(hstore->data);
+    Py_TYPE(self)->tp_free(self);
+}
+
+
+PyTypeObject HstoreType =
+{
+    PyVarObject_HEAD_INIT(0, 0)
+    .tp_name = "pglib.hstore",
+    .tp_basicsize = sizeof(Hstore),
+    .tp_dealloc = Hstore_dealloc,
+    .tp_flags = Py_TPFLAGS_DEFAULT,
+    .tp_new = Hstore_new
+};
