@@ -4,6 +4,8 @@
 
 struct Params;
 
+void Arrays_Init();
+
 bool BindArray(Params& params, PyObject* param);
 
 PyObject* GetInt4Array(const char* p);
@@ -11,5 +13,6 @@ PyObject* GetInt4Array(const char* p);
 
 PyObject* GetInt8Array(const char* p);
 PyObject* GetTextArray(const char* p);
+PyObject* GetDateArray(const char* p);
 
 #endif
