@@ -235,8 +235,11 @@ PyMODINIT_FUNC PyInit__pglib()
         return 0;
     }
 
-    if (PyType_Ready(&ConnectionType) < 0 || PyType_Ready(&ResultSetType) < 0 || PyType_Ready(&RowType) < 0)
+    if (PyType_Ready(&ConnectionType) < 0 || PyType_Ready(&ResultSetType) < 0
+        || PyType_Ready(&RowType) < 0 || PyType_Ready(&HstoreType) < 0)
+    {
         return 0;
+    }
 
     if (!DataTypes_Init())
         return 0;
@@ -271,5 +274,8 @@ PyMODINIT_FUNC PyInit__pglib()
     PyModule_AddObject(module, "ResultSet", (PyObject*)&ResultSetType);
     Py_INCREF((PyObject*)&ResultSetType);
 
+    PyModule_AddObject(module, "hstore", (PyObject*)&HstoreType);
+    Py_INCREF((PyObject*)&HstoreType);
+
     return module.Detach();
 }
