@@ -1,7 +1,10 @@
 
 # Run with pytest.
 
-import sys, threading
+# pylint: disable=missing-function-docstring,redefined-outer-name,unidiomatic-typecheck
+
+import sys, threading, gzip, uuid, locale
+from time import sleep
 from os.path import join, dirname, exists
 from decimal import Decimal
 from datetime import date, time, datetime, timedelta
@@ -10,7 +13,8 @@ import pytest
 from .import testutils
 testutils.add_to_path()
 
-import pglib, _pglib
+import pglib
+
 
 CONNINFO = 'dbname=test'
 
@@ -29,18 +33,16 @@ def cnxn():
     for i in range(3):
         try:
             cnxn.execute("drop table t%d" % i)
-        except:
+        except:                 # noqa
             pass
     yield cnxn
     cnxn.close()
 
 
-def _test_strtype(sqltype, value, resulttype=None, colsize=None):
+def _test_strtype(cnxn, sqltype, value, resulttype=None, colsize=None):
     assert colsize is None or isinstance(colsize, int), colsize
     assert colsize is None or (value is None or colsize >= len(value))
 
-    cnxn = pglib.connect(CONNINFO)
-
     if colsize:
         sql = "create table t1(s %s(%s))" % (sqltype, colsize)
     else:
@@ -65,7 +67,7 @@ def _test_strtype(sqltype, value, resulttype=None, colsize=None):
     assert v == value
 
 
-def _test_type(type, values, round_to=None, check_comparison=True):
+def _test_type(cnxn, type, values, round_to=None, check_comparison=True):
     """
     A generic function for testing inserting and selecting a single data type.
 
@@ -74,8 +76,6 @@ def _test_type(type, values, round_to=None, check_comparison=True):
     values: Either a single value or a list of values to insert and select.
         A column is created or each value.
     """
-    cnxn = pglib.connect(CONNINFO)
-
     if not isinstance(values, (tuple, list)):
         values = [values]
 
@@ -103,6 +103,7 @@ def _test_type(type, values, round_to=None, check_comparison=True):
         val = cnxn.fetchval(compare, *values)
         assert val, 'Comparison did not work: type %r values=%r' % (type, values)
 
+
 def test_execute_ddl(cnxn):
     """
     Ensure we can execute a DDL command and that it returns None.
@@ -159,7 +160,7 @@ def _datapath(filename):
 def test_copy_csv(cnxn):
     cnxn.execute("create table t1(a int, b varchar(20))")
     cnxn.copy_from_csv("t1", open(_datapath('test-noheader.csv')))
-    assert 2 == cnxn.scalar("select count(*) from t1")
+    assert cnxn.scalar("select count(*) from t1") == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
     assert row.b == 'two'
@@ -168,17 +169,16 @@ def test_copy_csv(cnxn):
 def test_copy_csv_header(cnxn):
     cnxn.execute("create table t1(a int, b varchar(20))")
     cnxn.copy_from_csv("t1", open(_datapath('test-header.csv')), header=True)
-    assert 2 == cnxn.scalar("select count(*) from t1")
+    assert cnxn.scalar("select count(*) from t1") == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
     assert row.b == 'two'
 
 
 def test_copy_csv_gzip(cnxn):
-    import gzip
     cnxn.execute("create table t1(a int, b varchar(20))")
     cnxn.copy_from_csv("t1", gzip.open(_datapath('test-header.csv.gz')), header=True)
-    assert 2 == cnxn.scalar("select count(*) from t1")
+    assert cnxn.scalar("select count(*) from t1") == 2
     row = cnxn.fetchrow("select a,b from t1 where a=2")
     assert row.a == 2
     assert row.b == 'two'
@@ -256,10 +256,10 @@ def test_fetchvals(cnxn):
     cnxn.execute("insert into t1 values (1, 'one'), (2, 'two'), (3, 'three')")
 
     values = cnxn.fetchvals("select a from t1 order by a")
-    assert values == [1,2,3]
+    assert values == [1, 2, 3]
 
     values = cnxn.fetchvals("select a, b from t1 order by a")
-    assert values == [1,2,3]
+    assert values == [1, 2, 3]
 
 #
 # resultset
@@ -358,7 +358,7 @@ def test_row_to_tuple(cnxn):
 
 
 def test_boolean(cnxn):
-    _test_type('boolean', [True, False])
+    _test_type(cnxn, 'boolean', [True, False])
 
 
 #
@@ -367,15 +367,15 @@ def test_boolean(cnxn):
 
 
 def test_smallint(cnxn):
-    _test_type('smallint', [-32768, -2, -1, 0, 1, 2, 32767])
+    _test_type(cnxn, 'smallint', [-32768, -2, -1, 0, 1, 2, 32767])
 
 
 def test_integer(cnxn):
-    _test_type('integer', [-2147483648, -32768, -2, -1, 0, 1, 2, 32767, 2147483647])
+    _test_type(cnxn, 'integer', [-2147483648, -32768, -2, -1, 0, 1, 2, 32767, 2147483647])
 
 
 def test_bigint(cnxn):
-    _test_type('bigint',
+    _test_type(cnxn, 'bigint',
                [-9223372036854775808, -2147483648, -32768, -2, -1, 0,
                 1, 2, 32767, 2147483647, 9223372036854775807])
 
@@ -383,26 +383,26 @@ def test_bigint(cnxn):
 def test_float4(cnxn):
     # Careful.  Python doesn't have a float4 datatype, so an float8 is returned.  Unfortunately this means values
     # won't always match even though they "look" like they do when you print them.
-    _test_type('float4', [1.2, -3.4], round_to=2, check_comparison=False)
+    _test_type(cnxn, 'float4', [1.2, -3.4], round_to=2, check_comparison=False)
 
 
 def test_float8(cnxn):
-    _test_type('float8', [1.2, -3.4], check_comparison=False)
+    _test_type(cnxn, 'float8', [1.2, -3.4], check_comparison=False)
 
 
 def test_decimal_fixed(cnxn):
     values = [Decimal(s) for s in ['123', '-3.0000000', '0', '123456.7890']]
-    _test_type('decimal(100,7)', values)
+    _test_type(cnxn, 'decimal(100,7)', values)
 
 
 def test_decimal_any(cnxn):
     values = [Decimal(s) for s in ['123', '-3.0000000', '0', '123456.7890']]
-    _test_type('decimal', values)
+    _test_type(cnxn, 'decimal', values)
 
 
 def test_money(cnxn):
     values = [Decimal(s) for s in ['1.23', '0.0', '123.45', '-12.34']]
-    _test_type('money', values, check_comparison=False)
+    _test_type(cnxn, 'money', values, check_comparison=False)
 
 
 # Decimal objects are constructed by first making a string, which we make in
@@ -413,17 +413,15 @@ def test_money(cnxn):
 
 
 def test_decimal_german(cnxn):
-    import locale
     locale.setlocale(locale.LC_ALL, 'de_DE')
     values = [Decimal(s) for s in ['-3.0000000', '123456.7890']]
-    _test_type('decimal(100,7)', values)
+    _test_type(cnxn, 'decimal(100,7)', values)
 
 
 def test_money_german(cnxn):
-    import locale
     locale.setlocale(locale.LC_ALL, 'de_DE')
     values = [Decimal(s) for s in ['1.23', '0.0', '123.45', '-12.34']]
-    _test_type('money', values, check_comparison=False)
+    _test_type(cnxn, 'money', values, check_comparison=False)
 
 
 def test_decimal_nan(cnxn):
@@ -450,14 +448,14 @@ def test_serial(cnxn):
 
 
 def test_varchar_null(cnxn):
-    _test_strtype('varchar', None, colsize=100)
+    _test_strtype(cnxn, 'varchar', None, colsize=100)
 
 
 # Generate a test for each fencepost size: test_varchar_0, etc.
 
 def _maketest(value):
     def t(cnxn):
-        _test_strtype('varchar', value, colsize=len(value))
+        _test_strtype(cnxn, 'varchar', value, colsize=len(value))
     return t
 
 
@@ -470,7 +468,7 @@ for value in STR_FENCEPOSTS:
 
 
 def test_char_null(cnxn):
-    _test_strtype('char', None, colsize=100)
+    _test_strtype(cnxn, 'char', None, colsize=100)
 
 
 # Generate a test for each fencepost size: test_char_1, etc.
@@ -479,7 +477,7 @@ def test_char_null(cnxn):
 
 def _maketest(value):
     def t(cnxn):
-        _test_strtype('char', value, colsize=len(value))
+        _test_strtype(cnxn, 'char', value, colsize=len(value))
     return t
 
 
@@ -515,7 +513,7 @@ def test_bytea(cnxn):
 
 
 def test_date(cnxn):
-    _test_type('date', date(2001, 2, 3))
+    _test_type(cnxn, 'date', date(2001, 2, 3))
 
 
 def test_time(cnxn):
@@ -593,6 +591,7 @@ def test_array_date(cnxn):
     result = cnxn.fetchval("select v from t1")
     assert result == value
 
+
 def test_array_int2(cnxn):
     cnxn.execute("create table t1(id int, v int[])")
     value = [None, -32768, -2, -1, 0, 1, 2, 32767]
@@ -600,6 +599,7 @@ def test_array_int2(cnxn):
     result = cnxn.fetchval("select v from t1")
     assert result == value
 
+
 def test_array_int4(cnxn):
     # Test with a 4-byte value
     cnxn.execute("create table t1(id int, v int[])")
@@ -772,7 +772,7 @@ def test_txn_status(cnxn):
     assert cnxn.transaction_status == pglib.PQTRANS_INTRANS
     try:
         cnxn.execute("drop table bogus")
-    except:
+    except:                     # noqa
         pass
     assert cnxn.transaction_status == pglib.PQTRANS_INERROR
 
@@ -781,7 +781,6 @@ def test_txn_status(cnxn):
 
 
 def test_uuid(cnxn):
-    import uuid
     value = uuid.UUID('4bfe4344-e7f2-41c3-ab88-1aecd79abd12')
     cnxn.execute("create table t1(a uuid)")
     cnxn.execute("insert into t1 values ($1)", value)
@@ -888,7 +887,7 @@ def test_txn_rollback_failure(cnxn):
     try:
         cnxn.begin()
         cnxn.execute("select x from bogus")  # table does not exists
-    except:
+    except:                                  # noqa
         cnxn.rollback()
 
 
@@ -927,8 +926,7 @@ def test_notifies(cnxn):
     # different channels anyway.
 
     def notify(conninfo):
-        import time
-        time.sleep(0.1)
+        sleep(0.1)
         other = pglib.connect(conninfo)
         other.execute("notify test2, 'testing'")
 
@@ -994,7 +992,7 @@ def test_hstore(cnxn):
     ]
 
     for value in values:
-        cnxn.execute("insert into t1(fields) values ($1)", value)
+        cnxn.execute("insert into t1(fields) values ($1)", pglib.hstore(value))
 
     rset = cnxn.execute("select fields from t1 order by id")
 
@@ -1034,21 +1032,16 @@ def test_name(cnxn):
     assert isinstance(name, str)
 
 
-def test_json_read(cnxn):
-    "Ensure we can read a JSON dictionary."
+def test_json(cnxn):
 
-    # json
+    value = {
+        'one': 1,
+        'a': [1, 2, 3],
+        '2': 'two'
+    }
 
-    val = cnxn.fetchval(
-        """
-        select json_build_object('a', 1, 'b', 'x')
-        """)
-    assert val == {'a': 1, 'b': 'x'}
+    cnxn.execute("create table t1(j json)")
+    cnxn.execute("insert into t1 values($1)", value)
+    result = cnxn.fetchval("select j from t1")
 
-    # jsonb
-
-    val = cnxn.fetchval(
-        """
-        select jsonb_build_object('a', 1, 'b', 'x')
-        """)
-    assert val == {'a': 1, 'b': 'x'}
+    assert value == result
